@@ -33,6 +33,7 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 
+#include "gdm-common.h"
 #include "gdm-display.h"
 #include "gdm-display-glue.h"
 #include "gdm-display-access-file.h"
@@ -361,8 +362,10 @@ gdm_display_real_get_timed_login_details (GdmDisplay *display,
          * can support auto/timed login on auxilliary seats in the
          * systemd path.
          */
-        if (g_strcmp0 (display->priv->seat_id, "seat0") != 0) {
-                goto out;
+        if (LOGIND_RUNNING()) {
+                if (g_strcmp0 (display->priv->seat_id, "seat0") != 0) {
+                        goto out;
+                }
         }
 #endif
 
