@@ -668,9 +668,6 @@ gdm_manager_handle_open_session (GdmDBusManager        *manager,
                                                                G_DBUS_ERROR,
                                                                G_DBUS_ERROR_ACCESS_DENIED,
                                                                _("User doesn't own session"));
-                g_prefix_error (&error, "Error while retrieving caller session id: ");
-                g_dbus_method_invocation_return_gerror (invocation, error);
-                g_error_free (error);
                 return TRUE;
         }
 
@@ -1135,7 +1132,8 @@ unexport_display (const char *id,
                   GdmDisplay *display,
                   GdmManager *manager)
 {
-    g_dbus_object_manager_server_unexport (manager->priv->object_manager, id);
+        if (!g_dbus_connection_is_closed (manager->priv->connection))
+                g_dbus_object_manager_server_unexport (manager->priv->object_manager, id);
 }
 
 static void
